@@ -6,7 +6,7 @@ from enum import Enum
 from alembic.config import Config
 from alembic import command
 
-alembic_cfg = Config()
+alembic_cfg = Config("./alembic.ini")
 
 cli = typer.Typer()
 
@@ -17,6 +17,8 @@ def init():
 
     typer.echo(typer.style("fetching data from", fg="green"))
 
+    f = open("guru99.txt", "w+")
+    f.close()
     command.init(alembic_cfg, "alembic", template="generic", package=True)
     return
 
